@@ -1,6 +1,6 @@
 /* m32r2 simulator support code
-   Copyright (C) 1997, 1998, 2003, 2007, 2008, 2009
-   Free Software Foundation, Inc.
+   Copyright (C) 1997-1998, 2003, 2007-2012 Free Software Foundation,
+   Inc.
    Contributed by Cygnus Support.
 
    This file is part of GDB, the GNU debugger.
